@@ -163,6 +163,8 @@ def __ensure_provisioning_reads(table_name, key_name, num_consec_read_checks):
             get_table_option(key_name, 'decrease_reads_with')
         decrease_reads_unit = \
             get_table_option(key_name, 'decrease_reads_unit')
+        min_provisioned_reads = \
+            get_table_option(key_name, 'min_provisioned_reads')
         max_provisioned_reads = \
             get_table_option(key_name, 'max_provisioned_reads')
         num_read_checks_before_scale_down = \
@@ -231,6 +233,32 @@ def __ensure_provisioning_reads(table_name, key_name, num_consec_read_checks):
                 update_needed = True
                 updated_read_units = calculated_provisioning
 
+    # Increase needed due to high throttling
+    elif throttled_read_count > throttled_reads_upper_threshold:
+
+        if throttled_reads_upper_threshold > 0:
+            if increase_reads_unit == 'percent':
+                calculated_provisioning = calculators.increase_reads_in_percent(
+                    updated_read_units,
+                    increase_reads_with,
+                    get_table_option(key_name, 'max_provisioned_reads'),
+                    table_name)
+            else:
+                calculated_provisioning = calculators.increase_reads_in_units(
+                    updated_read_units,
+                    increase_reads_with,
+                    get_table_option(key_name, 'max_provisioned_reads'),
+                    table_name)
+
+            if current_read_units != calculated_provisioning:
+                logger.info(
+                    '{0} - Resetting the number of consecutive '
+                    'read checks. Reason: scale up event detected'.format(
+                        table_name))
+                num_consec_read_checks = 0
+                update_needed = True
+                updated_read_units = calculated_provisioning
+
     # Decrease needed due to low CU consumption
     elif consumed_read_units_percent <= reads_lower_threshold:
 
@@ -261,32 +289,6 @@ def __ensure_provisioning_reads(table_name, key_name, num_consec_read_checks):
                     update_needed = True
                     updated_read_units = calculated_provisioning
 
-    # Increase needed due to high throttling
-    elif throttled_read_count > throttled_reads_upper_threshold:
-
-        if throttled_reads_upper_threshold > 0:
-            if increase_reads_unit == 'percent':
-                calculated_provisioning = calculators.increase_reads_in_percent(
-                    updated_read_units,
-                    increase_reads_with,
-                    get_table_option(key_name, 'max_provisioned_reads'),
-                    table_name)
-            else:
-                calculated_provisioning = calculators.increase_reads_in_units(
-                    updated_read_units,
-                    increase_reads_with,
-                    get_table_option(key_name, 'max_provisioned_reads'),
-                    table_name)
-
-            if current_read_units != calculated_provisioning:
-                logger.info(
-                    '{0} - Resetting the number of consecutive '
-                    'read checks. Reason: scale up event detected'.format(
-                        table_name))
-                num_consec_read_checks = 0
-                update_needed = True
-                updated_read_units = calculated_provisioning
-
     # Never go over the configured max provisioning
     if max_provisioned_reads:
         if int(updated_read_units) > int(max_provisioned_reads):
@@ -296,6 +298,15 @@ def __ensure_provisioning_reads(table_name, key_name, num_consec_read_checks):
                 'Will not increase writes over max-provisioned-reads '
                 'limit ({0} writes)'.format(updated_read_units))
 
+    # Ensure that we have met the min-provisioning
+    if min_provisioned_reads:
+        if int(min_provisioned_reads) > int(updated_read_units):
+            update_needed = True
+            updated_read_units = int(min_provisioned_reads)
+            logger.info(
+                '{0} - Increasing reads to meet min-provisioned-reads '
+                'limit ({1} reads)'.format(table_name, updated_read_units))
+
     logger.info('{0} - Consecutive read checks {1}/{2}'.format(
         table_name,
         num_consec_read_checks,
@@ -348,6 +359,8 @@ def __ensure_provisioning_writes(
             get_table_option(key_name, 'decrease_writes_unit')
         decrease_writes_with = \
             get_table_option(key_name, 'decrease_writes_with')
+        min_provisioned_writes = \
+            get_table_option(key_name, 'min_provisioned_writes')
         max_provisioned_writes = \
             get_table_option(key_name, 'max_provisioned_writes')
         num_write_checks_before_scale_down = \
@@ -419,6 +432,33 @@ def __ensure_provisioning_writes(
                 update_needed = True
                 updated_write_units = calculated_provisioning
 
+    # Increase needed due to high throttling
+    elif throttled_write_count > throttled_writes_upper_threshold:
+
+        if throttled_writes_upper_threshold > 0:
+            if increase_writes_unit == 'percent':
+                calculated_provisioning = \
+                    calculators.increase_writes_in_percent(
+                        current_write_units,
+                        increase_writes_with,
+                        get_table_option(key_name, 'max_provisioned_writes'),
+                        table_name)
+            else:
+                calculated_provisioning = calculators.increase_writes_in_units(
+                    current_write_units,
+                    increase_writes_with,
+                    get_table_option(key_name, 'max_provisioned_writes'),
+                    table_name)
+
+            if current_write_units != calculated_provisioning:
+                logger.info(
+                    '{0} - Resetting the number of consecutive '
+                    'write checks. Reason: scale up event detected'.format(
+                        table_name))
+                num_consec_write_checks = 0
+                update_needed = True
+                updated_write_units = calculated_provisioning
+
     # Decrease needed due to low CU consumption
     elif consumed_write_units_percent <= writes_lower_threshold:
 
@@ -451,33 +491,6 @@ def __ensure_provisioning_writes(
                     update_needed = True
                     updated_write_units = calculated_provisioning
 
-    # Increase needed due to high throttling
-    elif throttled_write_count > throttled_writes_upper_threshold:
-
-        if throttled_writes_upper_threshold > 0:
-            if increase_writes_unit == 'percent':
-                calculated_provisioning = \
-                    calculators.increase_writes_in_percent(
-                        current_write_units,
-                        increase_writes_with,
-                        get_table_option(key_name, 'max_provisioned_writes'),
-                        table_name)
-            else:
-                calculated_provisioning = calculators.increase_writes_in_units(
-                    current_write_units,
-                    increase_writes_with,
-                    get_table_option(key_name, 'max_provisioned_writes'),
-                    table_name)
-
-            if current_write_units != calculated_provisioning:
-                logger.info(
-                    '{0} - Resetting the number of consecutive '
-                    'write checks. Reason: scale up event detected'.format(
-                        table_name))
-                num_consec_write_checks = 0
-                update_needed = True
-                updated_write_units = calculated_provisioning
-
     # Never go over the configured max provisioning
     if max_provisioned_writes:
         if int(updated_write_units) > int(max_provisioned_writes):
@@ -487,6 +500,15 @@ def __ensure_provisioning_writes(
                 'Will not increase writes over max-provisioned-writes '
                 'limit ({0} writes)'.format(updated_write_units))
 
+    # Ensure that we have met the min-provisioning
+    if min_provisioned_writes:
+        if int(min_provisioned_writes) > int(updated_write_units):
+            update_needed = True
+            updated_write_units = int(min_provisioned_writes)
+            logger.info(
+                '{0} - Increasing writes to meet min-provisioned-writes '
+                'limit ({1} writes)'.format(table_name, updated_write_units))
+
     logger.info('{0} - Consecutive write checks {1}/{2}'.format(
         table_name,
         num_consec_write_checks,
