@@ -29,7 +29,7 @@ def get_consumed_read_units_percent(table_name, lookback_window_start=15):
 
     if metrics:
         consumed_read_units = int(
-            math.ceil(float(metrics[0]['Sum'])/float(lookback_window_start*60)))
+            math.ceil(float(metrics[0]['Sum'])/float(300)))
     else:
         consumed_read_units = 0
 
@@ -89,7 +89,7 @@ def get_consumed_write_units_percent(table_name, lookback_window_start=15):
 
     if metrics:
         consumed_write_units = int(
-            math.ceil(float(metrics[0]['Sum'])/float(lookback_window_start*60)))
+            math.ceil(float(metrics[0]['Sum'])/float(300)))
     else:
         consumed_write_units = 0
 
